@@ -1,5 +1,5 @@
 /* GSequencer - Advanced GTK Sequencer
- * Copyright (C) 2005-2017 Joël Krähemann
+ * Copyright (C) 2005-2019 Joël Krähemann
  *
  * This file is part of GSequencer.
  *
@@ -25,9 +25,17 @@
 
 #include <gtk/gtk.h>
 
+#include <ags/libags.h>
+#include <ags/libags-audio.h>
+#include <ags/libags-gui.h>
+
 #include <ags/X/editor/ags_select_note_dialog.h>
 
+G_BEGIN_DECLS
+
 void ags_select_note_dialog_response_callback(GtkWidget *dialog, gint response,
 					      AgsSelectNoteDialog *select_note_dialog);
 
+G_END_DECLS
+
 #endif /*__AGS_SELECT_NOTE_DIALOG_CALLBACKS_H__*/
